// dired_search() searches each entry in the dired buffer for a search
// pattern, and leaves only the entries that contain a match.

// dired_search() is useful when grep() seems like an overkill.  For
// example, you don't want to see all the lines that contain the match,
// just the file names.

// comments/suggestions/bug fixes welcome:
//    Morgwn McCarty
//    P.O. 1145
//    Eugene, OR  97440

// modification history:
// ---------------------
// > 5/24/94 10:30am --mm-- initial coding, v1.00

#include "eel.h"

char dired_search_string[FNAMELEN];		// save last search pattern

dired_search() on dired_tab['s'], dired_tab['S']
{
    int dired_buf;
    int search_buf;                     // temp search buf
    int flags = REGEX | RE_FASTEST;     // search flags
    int pos1;                           // temp point used for deleting a line
    char fname[FNAMELEN];               // current filename
    int num_found = 0;                  // number of files found with string

    point = 0;                          // move to top of dired buf
    nl_forward();
    flags = search_read(dired_search_string, "Search files for: ", flags);
    say("Searching...");
    dired_buf = bufnum;
    search_buf = name_to_bufnum(temp_buf()); // create temporary search buf
    while (point < size()) {
        dired_getname(fname);           // extract filename from dired buf
        bufnum = search_buf;            // switch to our search buffer
        if (file_read(fname, strip_returns.default) == EREADABORT) {
            say("Search aborted.");
            maybe_ding(bell_on_abort);
            bufnum = dired_buf;         // if aborted, end up in dired buf
            break;
        }
        if (re_search(1, dired_search_string)) { // if string found in file
            bufnum = dired_buf;         // go back to the dired buf
            nl_forward();               // and advance to the next entry
            num_found++;
        } else {                        // else
            bufnum = dired_buf;         // got back to the dired buf
            to_begin_line();            
            pos1 = point;
            nl_forward();
            delete(pos1, point);        // and delete the current line
        }           
        maybe_refresh();
    }
    buf_delete(search_buf);             // delete our temporary search buf
    say("Found %d files containing \"%s\".", num_found, dired_search_string);
    point = 0;                          // move to top of dired buf
    nl_forward();
}
